@@ -1,6 +1,6 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.07";
+our $VERSION = "2.08";
 
 use v5.14;
 use warnings;
@@ -270,16 +270,19 @@ my %csi_terminator = (
     # Non-standard
     CPR  => 'R', # Cursor Position Report – VT100 to Host
     STBM => 'r', # Set Top and Bottom Margins
+    SLRM => 's', # Set Left Right Margins
     );
 
 my %other_sequence = (
-    CSI => "\e[",       # Control Sequence Introducer
-    OSC => "\e]",       # Operating System Command
-    RIS => "\ec",       # Reset to Initial State
-    DECSC => "\e7",     # DEC Save Cursor
-    DECRC => "\e8",     # DEC Restore Cursor
-    DECEC => "\e[?25h", # DEC Enable Cursor
-    DECDC => "\e[?25l", # DEC Disable Cursor
+    CSI => "\e[",         # Control Sequence Introducer
+    OSC => "\e]",         # Operating System Command
+    RIS => "\ec",         # Reset to Initial State
+    DECSC => "\e7",       # DEC Save Cursor
+    DECRC => "\e8",       # DEC Restore Cursor
+    DECEC => "\e[?25h",   # DEC Enable Cursor
+    DECDC => "\e[?25l",   # DEC Disable Cursor
+    DECELRM => "\e[?69h", # DEC Enable Left Right Margin Mode
+    DECDLRM => "\e[?69l", # DEC Disable Left Right Margin Mode
     );
 
 sub csi_code {
@@ -366,6 +369,14 @@ sub cached_ansi_color {
     wantarray ? @result : join('', @result);
 }
 
+sub IsEOL {
+    <<"END";
+0000\t0000
+000A\t000D
+2028\t2029
+END
+}
+
 use Scalar::Util qw(blessed);
 
 sub apply_color {
@@ -383,9 +394,9 @@ sub apply_color {
 	my($s, $e, $el) = @{ $cache->{$color} //= [ ansi_pair($color) ] };
 	state $reset = qr{ \e\[[0;]*m (?: \e\[[0;]*[Km] )* }x;
 	if ($el) {
-	    s/(\A|(?<=[\r\n])|$reset)\K(?<x>[^\e\r\n]+|(?<!\n))/${s}$+{x}${e}/mg;
+	    s/(\A|(?<=\p{IsEOL})|$reset)\K(?<x>[^\e\p{IsEOL}]+|(?<!\n))/${s}$+{x}${e}/g;
 	} else {
-	    s/(\A|(?<=[\r\n])|$reset)\K(?<x>[^\e\r\n]+)/${s}$+{x}${e}/mg;
+	    s/(\A|(?<=\p{IsEOL})|$reset)\K(?<x>[^\e\p{IsEOL}]+)/${s}$+{x}${e}/g;
 	}
 	return $_;
     }
@@ -393,11 +404,11 @@ sub apply_color {
 	my($s, $e, $el) = @{ $cache->{$color} //= [ ansi_pair($color) ] };
 	state $reset = qr{ \e\[[0;]*m (?: \e\[[0;]*[Km] )* }x;
 	if ($el) {
-	    s/(?:\A|(?:[\r\n](?!\z)|$reset++))\K/${s}/g;
-	    s/([\r\n]|(?<![\r\n])\z)/${e}${1}/g;
+	    s/(?:\A|(?:\p{IsEOL}(?!\z)|$reset++))\K/${s}/g;
+	    s/(\p{IsEOL}|(?<!\p{IsEOL})\z)/${e}${1}/g;
 	} else {
-	    s/(?:\A|[\r\n]|$reset++)(?=.)\K/${s}/g;
-	    s/(?<!\e\[[Km])([\r\n]|(?<=[^\r\n])\z)/${e}${1}/g;
+	    s/(?:\A|\p{IsEOL}|$reset++)(?=.)\K/${s}/g;
+	    s/(?<!\e\[[Km])(\p{IsEOL}|(?<=\P{IsEOL})\z)/${e}${1}/g;
 	}
 	return $_;
     }
@@ -436,7 +447,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.07
+Version 2.08
 
 
 =head1 DESCRIPTION
@@ -686,6 +697,7 @@ And there are some non-standard CSI sequenes.
 
     CPR  n,m Cursor Position Report – VT100 to Host
     STBM n,m Set Top and Bottom Margins
+    SLRM n,m Set Left Right Margins
 
 These names can be followed by optional numerical parameters, using
 comma (C<,>) or semicolon (C<;>) to separate multiple ones, with
@@ -698,13 +710,15 @@ These sequences do not start with CSI, and do not take parameters.
 VT100 compatible terminal usually support these, and does not support
 C<SCP> and C<RCP> CSI code.
 
-    CSI    Control Sequence Introducer
-    OSC    Operating System Command
-    RIS    Reset to Initial State
-    DECSC  DEC Save Cursor
-    DECRC  DEC Restore Cursor
-    DECEC  DEC Enable Cursor
-    DECDC  DEC Disable Cursor
+    CSI      Control Sequence Introducer
+    OSC      Operating System Command
+    RIS      Reset to Initial State
+    DECSC    DEC Save Cursor
+    DECRC    DEC Restore Cursor
+    DECEC    DEC Enable Cursor
+    DECDC    DEC Disable Cursor
+    DECELRM  DEC Enable Left Right Margin Mode
+    DECDLRM  DEC Disable Left Right Margin Mode
 
 =head2 EXAMPLES
 
